@@ -66,11 +66,10 @@ public:
 
     bool autoTurnTop;
     bool highlighted;
-    bool graphicVisible;
 
     QSize graphicSize;
     QPointF layoutPos;
-    QSizeF spread;
+    QPointF spread;
 
     qreal topPadding;
     qreal rightPadding;
@@ -116,8 +115,7 @@ KCardPile::KCardPile( KCardScene * cardScene )
     d->autoTurnTop = false;
     d->highlighted = false;
     d->highlightValue = 0;
-    d->graphicVisible = true;
-    d->spread = QSizeF( 0, 0.33 );
+    d->spread = QPointF( 0, 0 );
 
     d->topPadding = 0;
     d->rightPadding = 0;
@@ -168,8 +166,7 @@ void KCardPile::paint( QPainter * painter, const QStyleOptionGraphicsItem * opti
     Q_UNUSED( option );
     Q_UNUSED( widget );
 
-    if ( d->graphicVisible )
-        paintGraphic( painter, d->highlightValue );
+    paintGraphic( painter, d->highlightValue );
 }
 
 
@@ -205,7 +202,7 @@ KCard * KCardPile::at( int index ) const
 }
 
 
-KCard *KCardPile::top() const
+KCard * KCardPile::topCard() const
 {
     if ( d->cards.isEmpty() )
         return 0;
@@ -214,6 +211,18 @@ KCard *KCardPile::top() const
 }
 
 
+QList<KCard*> KCardPile::topCards( int depth ) const
+{
+    if ( depth <= 0 )
+        return QList<KCard*>();
+
+    if ( depth > count() )
+        return d->cards;
+
+    return d->cards.mid( count() - depth );
+}
+
+
 QList<KCard*> KCardPile::topCardsDownTo( const KCard * card ) const
 {
     int index = d->cards.indexOf( const_cast<KCard*>( card ) );
@@ -322,7 +331,7 @@ qreal KCardPile::leftPadding() const
 }
 
 
-void KCardPile::setSpread( QSizeF spread )
+void KCardPile::setSpread( QPointF spread )
 {
     d->spread = spread;
 }
@@ -330,11 +339,11 @@ void KCardPile::setSpread( QSizeF spread )
 
 void KCardPile::setSpread( qreal width, qreal height )
 {
-    setSpread( QSizeF( width, height ) );
+    setSpread( QPointF( width, height ) );
 }
 
 
-QSizeF KCardPile::spread() const
+QPointF KCardPile::spread() const
 {
     return d->spread;
 }
@@ -407,22 +416,6 @@ bool KCardPile::isHighlighted() const
 }
 
 
-void KCardPile::setGraphicVisible( bool visible )
-{
-    if ( d->graphicVisible != visible )
-    {
-        d->graphicVisible = visible;
-        update();
-    }
-}
-
-
-bool KCardPile::isGraphicVisible()
-{
-    return d->graphicVisible;
-}
-
-
 void KCardPile::add( KCard * card )
 {
     insert( card, d->cards.size() );
@@ -472,78 +465,6 @@ void KCardPile::swapCards( int index1, int index2 )
 }
 
 
-void KCardPile::layoutCards( int duration )
-{
-    KCardScene * kcs = dynamic_cast<KCardScene*>( scene() );
-
-    if ( !kcs || d->cards.isEmpty() )
-        return;
-
-    const QSize cardSize = kcs->deck()->cardSize();
-
-    qreal minX = 0;
-    qreal maxX = 0;
-    qreal minY = 0;
-    qreal maxY = 0;
-    QPointF totalOffset( 0, 0 );
-    for ( int i = 1; i < d->cards.size(); ++i )
-    {
-        totalOffset += cardOffset( d->cards[i] );
-        minX = qMin( minX, totalOffset.x() );
-        maxX = qMax( maxX, totalOffset.x() );
-        minY = qMin( minY, totalOffset.y() );
-        maxY = qMax( maxY, totalOffset.y() );
-    }
-
-    QPointF absLayoutPos = layoutPos();
-    if ( absLayoutPos.x() < 0 )
-        absLayoutPos.rx() += kcs->contentArea().width() / cardSize.width() - 1;
-    if ( absLayoutPos.y() < 0 )
-        absLayoutPos.ry() += kcs->contentArea().height() / cardSize.height() - 1;
-
-    QRectF available = kcs->spaceAllottedToPile( this );
-    qreal availableTop = absLayoutPos.y() - available.top();
-    qreal availableBottom = available.bottom() - (absLayoutPos.y() + 1);
-    qreal availableLeft = absLayoutPos.x() - available.left();
-    qreal availableRight = available.right() - (absLayoutPos.x() + 1);
-
-    qreal scaleTop = 1;
-    if ( minY < 0 )
-        scaleTop = qMin<qreal>( availableTop / -minY, 1 );
-    qreal scaleBottom = 1;
-    if ( maxY > 0 )
-        scaleBottom = qMin<qreal>( availableBottom / maxY, 1 );
-    qreal scaleY = qMin( scaleTop, scaleBottom );
-
-    qreal scaleLeft = 1;
-    if ( minX < 0 )
-        scaleLeft = qMin<qreal>( availableLeft / -minX, 1 );
-    qreal scaleRight = 1;
-    if ( maxX > 0 )
-        scaleRight = qMin<qreal>( availableRight / maxX, 1 );
-    qreal scaleX = qMin( scaleLeft, scaleRight );
-
-    QPointF cardPos = pos();
-    qreal z = zValue() + 1;
-
-    for ( int i = 0; i < d->cards.size() - 1; ++i )
-    {
-        KCard * card = d->cards[i];
-        card->animate( cardPos, z, 0, card->isFaceUp(), false, duration );
-
-        QPointF offset = cardOffset( card );
-        cardPos.rx() += scaleX * offset.x() * cardSize.width();
-        cardPos.ry() += scaleY * offset.y() * cardSize.height();
-        ++z;
-    }
-
-    if ( d->autoTurnTop && !top()->isFaceUp() )
-        top()->animate( cardPos, z, 0, true, false, duration );
-    else
-        top()->animate( cardPos, z, 0, top()->isFaceUp(), false, duration );
-}
-
-
 void KCardPile::paintGraphic( QPainter * painter, qreal highlightedness )
 {
     int penWidth = boundingRect().width() / 40;
@@ -555,12 +476,12 @@ void KCardPile::paintGraphic( QPainter * painter, qreal highlightedness )
 }
 
 
-QPointF KCardPile::cardOffset( const KCard * card ) const
+QList<QPointF> KCardPile::cardPositions() const
 {
-    QPointF offset( spread().width(), spread().height() );
-    if (!card->isFaceUp())
-        offset *= 0.6;
-    return offset;
+    QList<QPointF> positions;
+    for ( int i = 0; i < count(); ++i )
+        positions << i * spread();
+    return positions;
 }
 
 
